@@ -260,7 +260,7 @@ class Scaffold(object):
         need_import_users = True
         need_import_token = True
         need_import_JsonResponse = True
-        # need_import_all = True
+        need_import_all = True
 
         for line in import_file.readlines():
             if 'from django.shortcuts import render, redirect, get_object_or_404' in line:
@@ -273,18 +273,8 @@ class Scaffold(object):
                 need_import_token = False
             if 'from django3scaffold.http import JsonResponse' in line:
                 need_import_JsonResponse = False
-#             if """import json
-# from drf_yasg import openapi
-# from django.core import serializers
-# from django.http import JsonResponse
-# from drf_yasg.utils import swagger_auto_schema
-# from rest_framework.permissions import AllowAny
-# from django.views.decorators.cache import never_cache
-# from rest_framework.permissions import IsAuthenticated
-# from rest_framework.decorators import permission_classes
-# from rest_framework.decorators import api_view, renderer_classes
-# from drf_yasg.renderers import SwaggerUIRenderer, OpenAPIRenderer""" in line:
-#                 need_import_all = False
+            if "from drf_yasg.renderers import SwaggerUIRenderer, OpenAPIRenderer" in line:
+                need_import_all = False
 
         if need_import_shortcut:
             import_list.append('from django.shortcuts import render, redirect, get_object_or_404')
@@ -296,6 +286,18 @@ class Scaffold(object):
             import_list.append('from django.middleware.csrf import get_token')
         if need_import_JsonResponse:
             import_list.append('from django3scaffold.http import JsonResponse')
+        if need_import_all:
+            import_list.append('import json')
+            import_list.append('from drf_yasg import openapi')
+            import_list.append('from django.core import serializers')
+            import_list.append('from django.http import JsonResponse')
+            import_list.append('from drf_yasg.utils import swagger_auto_schema')
+            import_list.append('from rest_framework.permissions import AllowAny')
+            import_list.append('from django.views.decorators.cache import never_cache')
+            import_list.append('from rest_framework.permissions import IsAuthenticated')
+            import_list.append('from rest_framework.decorators import permission_classes')
+            import_list.append('from rest_framework.decorators import api_view, renderer_classes')
+            import_list.append('from drf_yasg.renderers import SwaggerUIRenderer, OpenAPIRenderer')
 
         return import_list
 
